public final class FileFacadeKt /* FileFacadeKt*/ {
  @org.jetbrains.annotations.NotNull()
  private static final java.lang.String notNullVal;

  @org.jetbrains.annotations.NotNull()
  private static final java.lang.String privateNn;

  @org.jetbrains.annotations.NotNull()
  private static java.lang.String notNullVar;

  @org.jetbrains.annotations.Nullable()
  private static final java.lang.String nullableVal;

  @org.jetbrains.annotations.Nullable()
  private static final java.lang.String privateN;

  @org.jetbrains.annotations.Nullable()
  private static java.lang.String nullableVar;

  @org.jetbrains.annotations.NotNull()
  @org.jetbrains.annotations.Nullable()
  public static final java.lang.String getNotNullValWithGet();//  getNotNullValWithGet()

  @org.jetbrains.annotations.NotNull()
  @org.jetbrains.annotations.Nullable()
  public static final java.lang.String getNotNullVarWithGetSet();//  getNotNullVarWithGetSet()

  @org.jetbrains.annotations.NotNull()
  @org.jetbrains.annotations.Nullable()
  public static final java.lang.String getNullableValWithGet();//  getNullableValWithGet()

  @org.jetbrains.annotations.NotNull()
  @org.jetbrains.annotations.Nullable()
  public static final java.lang.String getNullableVarWithGetSet();//  getNullableVarWithGetSet()

  @org.jetbrains.annotations.NotNull()
  @org.jetbrains.annotations.Nullable()
  public static final java.lang.String notNullWithN();//  notNullWithN()

  @org.jetbrains.annotations.NotNull()
  @org.jetbrains.annotations.Nullable()
  public static final java.lang.String nullableWithNN();//  nullableWithNN()

  @org.jetbrains.annotations.NotNull()
  public static final java.lang.String getNotNullVal();//  getNotNullVal()

  @org.jetbrains.annotations.NotNull()
  public static final java.lang.String getNotNullVar();//  getNotNullVar()

  @org.jetbrains.annotations.NotNull()
  public static final java.lang.String notNull(@org.jetbrains.annotations.NotNull() java.lang.String);//  notNull(java.lang.String)

  @org.jetbrains.annotations.NotNull()
  public static final java.lang.String notNullWithNN();//  notNullWithNN()

  @org.jetbrains.annotations.NotNull()
  public static final void setNullableVarWithGetSet(@org.jetbrains.annotations.Nullable() java.lang.String);//  setNullableVarWithGetSet(java.lang.String)

  @org.jetbrains.annotations.Nullable()
  public static final java.lang.String getNullableVal();//  getNullableVal()

  @org.jetbrains.annotations.Nullable()
  public static final java.lang.String getNullableVar();//  getNullableVar()

  @org.jetbrains.annotations.Nullable()
  public static final java.lang.String nullable(@org.jetbrains.annotations.Nullable() java.lang.String);//  nullable(java.lang.String)

  @org.jetbrains.annotations.Nullable()
  public static final java.lang.String nullableWithN();//  nullableWithN()

  @org.jetbrains.annotations.Nullable()
  public static final void setNotNullVarWithGetSet(@org.jetbrains.annotations.NotNull() java.lang.String);//  setNotNullVarWithGetSet(java.lang.String)

  private static final java.lang.String privateFun(java.lang.String, java.lang.String);//  privateFun(java.lang.String, java.lang.String)

  public static final void setNotNullVar(@org.jetbrains.annotations.NotNull() java.lang.String);//  setNotNullVar(java.lang.String)

  public static final void setNullableVar(@org.jetbrains.annotations.Nullable() java.lang.String);//  setNullableVar(java.lang.String)
}
