public final class Class /* Class*/ {
  @org.jetbrains.annotations.NotNull()
  private @org.jetbrains.annotations.NotNull() java.lang.String notNullVar;

  @org.jetbrains.annotations.NotNull()
  private final @org.jetbrains.annotations.NotNull() java.lang.String notNullVal;

  @org.jetbrains.annotations.NotNull()
  private final @org.jetbrains.annotations.NotNull() java.lang.String privateNN;

  @org.jetbrains.annotations.Nullable()
  private @org.jetbrains.annotations.Nullable() java.lang.String nullableVar;

  @org.jetbrains.annotations.Nullable()
  private final @org.jetbrains.annotations.Nullable() java.lang.String nullableVal;

  @org.jetbrains.annotations.Nullable()
  private final @org.jetbrains.annotations.Nullable() java.lang.String privateN;

  public @org.jetbrains.annotations.NotNull() java.lang.String lateInitVar;

  @<error>()
  @org.jetbrains.annotations.NotNull()
  public final @org.jetbrains.annotations.NotNull() java.lang.String getNotNullValWithGet();//  getNotNullValWithGet()

  @<error>()
  @org.jetbrains.annotations.NotNull()
  public final @org.jetbrains.annotations.NotNull() java.lang.String getNotNullVarWithGetSet();//  getNotNullVarWithGetSet()

  @<error>()
  @org.jetbrains.annotations.NotNull()
  public final @org.jetbrains.annotations.NotNull() java.lang.String notNullWithN();//  notNullWithN()

  @<error>()
  @org.jetbrains.annotations.NotNull()
  public final @org.jetbrains.annotations.NotNull() java.lang.String notNullWithNN();//  notNullWithNN()

  @<error>()
  @org.jetbrains.annotations.Nullable()
  public final @org.jetbrains.annotations.Nullable() java.lang.String getNullableValWithGet();//  getNullableValWithGet()

  @<error>()
  @org.jetbrains.annotations.Nullable()
  public final @org.jetbrains.annotations.Nullable() java.lang.String getNullableVarWithGetSet();//  getNullableVarWithGetSet()

  @<error>()
  @org.jetbrains.annotations.Nullable()
  public final @org.jetbrains.annotations.Nullable() java.lang.String nullableWithN();//  nullableWithN()

  @<error>()
  @org.jetbrains.annotations.Nullable()
  public final @org.jetbrains.annotations.Nullable() java.lang.String nullableWithNN();//  nullableWithNN()

  @<error>()
  public final void setNotNullVarWithGetSet(@org.jetbrains.annotations.NotNull() @org.jetbrains.annotations.NotNull() java.lang.String);//  setNotNullVarWithGetSet(@org.jetbrains.annotations.NotNull() java.lang.String)

  @<error>()
  public final void setNullableVarWithGetSet(@org.jetbrains.annotations.Nullable() @org.jetbrains.annotations.Nullable() java.lang.String);//  setNullableVarWithGetSet(@org.jetbrains.annotations.Nullable() java.lang.String)

  @org.jetbrains.annotations.NotNull()
  public final @org.jetbrains.annotations.NotNull() java.lang.String getLateInitVar();//  getLateInitVar()

  @org.jetbrains.annotations.NotNull()
  public final @org.jetbrains.annotations.NotNull() java.lang.String getNotNullVal();//  getNotNullVal()

  @org.jetbrains.annotations.NotNull()
  public final @org.jetbrains.annotations.NotNull() java.lang.String getNotNullVar();//  getNotNullVar()

  @org.jetbrains.annotations.NotNull()
  public final @org.jetbrains.annotations.NotNull() java.lang.String notNull(@org.jetbrains.annotations.NotNull() @org.jetbrains.annotations.NotNull() java.lang.String);//  notNull(@org.jetbrains.annotations.NotNull() java.lang.String)

  @org.jetbrains.annotations.Nullable()
  public final @org.jetbrains.annotations.Nullable() java.lang.String getNullableVal();//  getNullableVal()

  @org.jetbrains.annotations.Nullable()
  public final @org.jetbrains.annotations.Nullable() java.lang.String getNullableVar();//  getNullableVar()

  @org.jetbrains.annotations.Nullable()
  public final @org.jetbrains.annotations.Nullable() java.lang.String nullable(@org.jetbrains.annotations.Nullable() @org.jetbrains.annotations.Nullable() java.lang.String);//  nullable(@org.jetbrains.annotations.Nullable() java.lang.String)

  public  Class();//  .ctor()

  public final void setLateInitVar(@org.jetbrains.annotations.NotNull() @org.jetbrains.annotations.NotNull() java.lang.String);//  setLateInitVar(@org.jetbrains.annotations.NotNull() java.lang.String)

  public final void setNotNullVar(@org.jetbrains.annotations.NotNull() @org.jetbrains.annotations.NotNull() java.lang.String);//  setNotNullVar(@org.jetbrains.annotations.NotNull() java.lang.String)

  public final void setNullableVar(@org.jetbrains.annotations.Nullable() @org.jetbrains.annotations.Nullable() java.lang.String);//  setNullableVar(@org.jetbrains.annotations.Nullable() java.lang.String)
}
